==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/5e/5ec68bf869dc33d3c280ea86fbbee30a.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/SmsBundle/Api/AbstractSmsApi.php */
class __TwigTemplate_6736c8e60ba0efd3f557db0730a5adbc extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\SmsBundle\\Api;

use Mautic\\LeadBundle\\Entity\\Lead;
use Mautic\\PageBundle\\Model\\TrackableModel;
use Mautic\\SmsBundle\\Sms\\TransportInterface;

/**
 * @deprecated use TransportInterface instead
 */
abstract class AbstractSmsApi implements TransportInterface
{
    public function __construct(
        protected TrackableModel \$pageTrackableModel
    ) {
    }

    /**
     * @param string \$content
     *
     * @return mixed
     */
    abstract public function sendSms(Lead \$lead, \$content);

    /**
     * Convert a non-tracked url to a tracked url.
     *
     * @param string \$url
     *
     * @return string
     */
    public function convertToTrackedUrl(\$url, array \$clickthrough = [])
    {
        /* @var \\Mautic\\PageBundle\\Entity\\Redirect \$redirect */
        \$trackable = \$this->pageTrackableModel->getTrackableByUrl(\$url, 'sms', \$clickthrough['sms']);

        return \$this->pageTrackableModel->generateTrackableUrl(\$trackable, \$clickthrough, true);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/SmsBundle/Api/AbstractSmsApi.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/SmsBundle/Api/AbstractSmsApi.php", "/var/www/mautic-ktn/app/bundles/SmsBundle/Api/AbstractSmsApi.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/5e/5ec68bf869dc33d3c280ea86fbbee30a.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/SmsBundle/Api/AbstractSmsApi.php */
class __TwigTemplate_6736c8e60ba0efd3f557db0730a5adbc extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\SmsBundle\\Api;

use Mautic\\LeadBundle\\Entity\\Lead;
use Mautic\\PageBundle\\Model\\TrackableModel;
use Mautic\\SmsBundle\\Sms\\TransportInterface;

/**
 * @deprecated use TransportInterface instead
 */
abstract class AbstractSmsApi implements TransportInterface
{
    public function __construct(
        protected TrackableModel \$pageTrackableModel
    ) {
    }

    /**
     * @param string \$content
     *
     * @return mixed
     */
    abstract public function sendSms(Lead \$lead, \$content);

    /**
     * Convert a non-tracked url to a tracked url.
     *
     * @param string \$url
     *
     * @return string
     */
    public function convertToTrackedUrl(\$url, array \$clickthrough = [])
    {
        /* @var \\Mautic\\PageBundle\\Entity\\Redirect \$redirect */
        \$trackable = \$this->pageTrackableModel->getTrackableByUrl(\$url, 'sms', \$clickthrough['sms']);

        return \$this->pageTrackableModel->generateTrackableUrl(\$trackable, \$clickthrough, true);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/SmsBundle/Api/AbstractSmsApi.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/SmsBundle/Api/AbstractSmsApi.php", "/var/www/html/mauticGIT-Test/app/bundles/SmsBundle/Api/AbstractSmsApi.php");
    }
}
